"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const get = require("lodash.get");
const set = require("lodash.set");
const rehydrate = (storage, stores) => {
    return new Promise((resolve) => {
        let callbacksNeeded = stores.length;
        const tryResolve = () => {
            callbacksNeeded--;
            if (callbacksNeeded === 0) {
                resolve();
            }
        };
        for (const store of stores) {
            storage.getItem(`store.${store.name}`, (err, objString) => {
                const obj = JSON.parse(objString);
                for (const key of store.getPropKeys()) {
                    const oldValue = get(obj, key);
                    if (oldValue !== undefined && oldValue !== null) {
                        set(store, key, oldValue);
                    }
                }
                const untypedStore = store;
                untypedStore.trigger(store.rehydratedKeys);
                tryResolve();
            });
        }
    });
};
exports.default = rehydrate;
//# sourceMappingURL=rehydrate.js.map